.. image:: https://travis-ci.org/ambitioninc/django-entity-history.png
   :target: https://travis-ci.org/ambitioninc/django-entity-history

.. image:: https://coveralls.io/repos/ambitioninc/django-entity-history/badge.png?branch=develop
    :target: https://coveralls.io/r/ambitioninc/django-entity-history?branch=develop

.. image:: https://img.shields.io/pypi/v/django-entity-history.svg
    :target: https://crate.io/packages/django-entity-history/
    :alt: Latest PyPI version

.. image:: https://img.shields.io/pypi/dm/django-entity-history.svg
    :target: https://crate.io/packages/django-entity-history/
    :alt: Number of PyPI downloads


django-entity-history
=====================


I have failed to provide a good README.rst in my project, and you should shun
me if I do any pull requests

Installation
------------
To install the latest release, type::

    pip install django-entity-history

To install the latest code directly from source, type::

    pip install git+git://github.com/ambitioninc/django-entity-history.git

Documentation
-------------

Full documentation is available at http://django-entity-history.readthedocs.org

License
-------
MIT License (see LICENSE)